@@ -5,8 +5,8 @@ import datetime
 
 from pyathenajdbc.error import *  # noqa
 
-__version__ = "2.0.8"
-__athena_driver_version__ = "2.0.9"
+__version__ = "2.1.0"
+__athena_driver_version__ = "2.0.13"
 
 # Globals https://www.python.org/dev/peps/pep-0249/#globals
 apilevel = "2.0"
@@ -76,39 +76,7 @@ Time = datetime.time
 Timestamp = datetime.datetime
 
 
-def connect(
-    s3_staging_dir=None,
-    access_key=None,
-    secret_key=None,
-    region_name=None,
-    schema_name="default",
-    profile_name=None,
-    credential_file=None,
-    jvm_path=None,
-    jvm_options=None,
-    converter=None,
-    formatter=None,
-    driver_path=None,
-    log4j_conf=None,
-    work_group=None,
-    **kwargs
-):
+def connect(*args, **kwargs):
     from pyathenajdbc.connection import Connection
 
-    return Connection(
-        s3_staging_dir,
-        access_key,
-        secret_key,
-        region_name,
-        schema_name,
-        profile_name,
-        credential_file,
-        jvm_path,
-        jvm_options,
-        converter,
-        formatter,
-        driver_path,
-        log4j_conf,
-        work_group,
-        **kwargs
-    )
+    return Connection(*args, **kwargs)
